==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+77"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation type="unfinished">Położenie</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Obracanie:</translatorcomment>
        <translation type="unfinished">Obracanie:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Obróć wklejone podmioty &lt;br&gt; przez to kąt</translation>
    </message>
    <message>
        <location line="+97"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Skala:</translatorcomment>
        <translation type="unfinished">Skala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Skala wklejone podmioty &lt;br&gt; tym czynnikiem</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przerzuć wklejone podmioty &lt;br&gt; poziomo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przerzuć wklejone podmioty &lt;br&gt; pionowo</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Wklej wszystkie podmioty &lt;br&gt; do bieżącej warstwy &lt;br&gt; Zamiast warstwy pierwotnego</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translatorcomment>--ignored case--
--file: qcadactions_pl.ts--
Do bieżącej warstwy
Użyj bieżącej warstwy</translatorcomment>
        <translation type="unfinished">Do bieżącej warstwy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zastąp istniejące warstwy &lt;br&gt; w rysowanie &lt;br&gt; warstwy ze schowka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zastąp warstw</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zastąp istniejące bloki &lt;br&gt; w rysowanie &lt;br&gt; bloki z schowka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Zastąp bloki</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Wklej</translatorcomment>
        <translation type="unfinished">&amp;Wklej</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Edit/Paste/ts/Paste_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Paste</name>
    <message>
        <location filename="../Paste.js" line="+52"/>
        <source>Edit</source>
        <translation>Edycja</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Paste</source>
        <translation>Wklej</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Position</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
Wskaż położenie linii wymiarowej lub wprowadź kąt:
Wskaż położenie linii wymiarowej lub wprowadź kąt
Wskaż pozycje</translatorcomment>
        <translation>Położenie</translation>
    </message>
    <message>
        <location filename="../Paste.ui" line="+17"/>
        <source>Rotation:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Obracanie:</translatorcomment>
        <translation>Obrót:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Rotate pasted entities&lt;br&gt;by this angle</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Obraca wklejone obiekty o zadany kąt</translation>
    </message>
    <message>
        <location line="+107"/>
        <source>Scale:</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Skala:</translatorcomment>
        <translation>Skala:</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Scale pasted entities&lt;br&gt;by this factor</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Skaluje wklejone obiekty przez zadany współczynnik</translation>
    </message>
    <message>
        <location line="+72"/>
        <source>Flip pasted entities&lt;br&gt;horizontally</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odbij lustrzanie wklejony obiekty poziomo</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Flip pasted entities&lt;br&gt;vertically</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Odbij lustrzanie wklejone obiekty pionowo</translation>
    </message>
    <message>
        <location line="+21"/>
        <source>Paste all entities&lt;br&gt;to current layer&lt;br&gt;instead of original layer</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Wkleja wszystkie obiekty do aktualnej warstwy zamiast pierwotnej warstwy</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>To current layer</source>
        <translatorcomment>--ignored case--
--file: qcadactions_pl.ts--
Do bieżącej warstwy
Użyj bieżącej warstwy</translatorcomment>
        <translation>Do aktualnej warstwy</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing layers&lt;br&gt;in drawing with&lt;br&gt;layers from clipboard</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastępuje istniejące warstwy rysunku warstwami ze schowka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite layers</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastąpienie warstw</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Overwrite existing blocks&lt;br&gt;in drawing with&lt;br&gt;blocks from clipboard</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastępuje istniejące bloki rysunku blokami ze schowka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Overwrite blocks</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Zastąpienie bloków</translation>
    </message>
    <message>
        <location filename="../PasteInit.js" line="+2"/>
        <source>&amp;Paste</source>
        <translatorcomment>--exact match--
--file: qt_pl.ts--
&amp;Wklej</translatorcomment>
        <translation>&amp;Wklej</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Reset to defaults every time tool is used</source>
        <translation>Przywrócenie ustawień domyślnych za każdym użyciem narzędzia</translation>
    </message>
</context>
</TS>
